@@ -393,11 +393,12 @@ class PreprocessInput:
         self.rescale_mode = rescale_mode
         self.input_shape = input_shape[1:-1] if len(input_shape) == 4 else input_shape[:2]
 
-    def __call__(self, image, resize_method="bilinear"):
+    def __call__(self, image, resize_method="bilinear", resize_antialias=False, input_shape=None):
+        input_shape = self.input_shape if input_shape is None else input_shape[:2]
         image = tf.convert_to_tensor(image)
         if tf.reduce_max(image) < 2:
             image *= 255
-        image = tf.image.resize(image, self.input_shape, method=resize_method)
+        image = tf.image.resize(image, input_shape, method=resize_method, antialias=resize_antialias)
         if len(image.shape) == 3:
             image = tf.expand_dims(image, 0)
 
@@ -407,13 +408,13 @@ class PreprocessInput:
             return tf.keras.applications.imagenet_utils.preprocess_input(image, mode=self.rescale_mode)
 
 
-def decode_predictions(preds, top=5):
+def imagenet_decode_predictions(preds, top=5):
     preds = preds.numpy() if isinstance(preds, tf.Tensor) else preds
     return tf.keras.applications.imagenet_utils.decode_predictions(preds, top=5)
 
 
-def add_pre_post_process(model, rescale_mode="tf", input_shape=None):
+def add_pre_post_process(model, rescale_mode="tf", input_shape=None, post_process=None):
     input_shape = model.input_shape[1:-1] if input_shape is None else input_shape
     model.preprocess_input = PreprocessInput(input_shape, rescale_mode=rescale_mode)
-    model.decode_predictions = decode_predictions
+    model.decode_predictions = imagenet_decode_predictions if post_process is None else post_process
     model.rescale_mode = rescale_mode
